import { transform, processExtraFields, processSections, getReadingTime } from './index';
import pages from '~tests/factories/pages/pages.factory.js';
import getPageList from '~tests/factories/pages/page.factory';
import multipleMarketsPages from '~tests/factories/pages/multiple-markets-pages.factory.js';

const tempContent = {
  value: `What is Lorem Ipsum?
  Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.        
  Why do we use it?
  It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of using Lorem Ipsum is that it has a more-or-less normal distribution of letters, as opposed to using 'Content here, content here', making it look like readable English. Many desktop publishing packages and web page editors now use Lorem Ipsum as their default model text, and a search for 'lorem ipsum' will uncover many web sites still in their infancy. Various versions have evolved over the years, sometimes by accident, sometimes on purpose (injected humour and the like).        
  Where does it come from?
  Contrary to popular belief, Lorem Ipsum is not simply random text. It has roots in a piece of classical Latin literature from 45 BC, making it over 2000 years old. Richard McClintock, a Latin professor at Hampden-Sydney College in Virginia, looked up one of the more obscure Latin words, consectetur, from a Lorem Ipsum passage, and going through the cites of the word in classical literature, discovered the undoubtable source. Lorem Ipsum comes from sections 1.10.32 and 1.10.33 of "de Finibus Bonorum et Malorum" (The Extremes of Good and Evil) by Cicero, written in 45 BC. This book is a treatise on the theory of ethics, very popular during the Renaissance. The first line of Lorem Ipsum, "Lorem ipsum dolor sit amet..", comes from a line in section 1.10.32.
  The standard chunk of Lorem Ipsum used since the 1500s is reproduced below for those interested. Sections 1.10.32 and 1.10.33 from "de Finibus Bonorum et Malorum" by Cicero are also reproduced in their exact original form, accompanied by English versions from the 1914 translation by H. Rackham.
  Where can I get some?
  There are many variations of passages of Lorem Ipsum available, but the majority have suffered alteration in some form, by injected humour, or randomised words which don't look even slightly believable. If you are going to use a passage of Lorem Ipsum, you need to be sure there isn't anything embarrassing hidden in the middle of text. All the Lorem Ipsum generators on the Internet tend to repeat predefined chunks as necessary, making this the first true generator on the Internet. It uses a dictionary of over 200 Latin words, combined with a handful of model sentence structures, to generate Lorem Ipsum which looks reasonable. The generated Lorem Ipsum is therefore always free from repetition, injected humour, or non-characteristic words etc.`,
  name: 'content',
};

describe('Index Processor', () => {
  test('Transform', () => {
    const results = transform(pages);
    expect(results?.za_en?.page).toBeTruthy();
  });

  test('Transform multiple markets', () => {
    const results = transform(multipleMarketsPages);
    Object.keys(multipleMarketsPages.site_markets).forEach((siteMarket) => {
      const prefix = multipleMarketsPages.site_markets[siteMarket].path_prefix;
      expect(results[siteMarket].page[0].path).toBe(`${prefix ? `${prefix}/` : ''}test-page`);
    });
  });

  test('processExtraFields', () => {
    const extraFields = {
      logos: { value: 339, type: 'default' },
    };
    processExtraFields(extraFields);
    expect(extraFields?.logos).toBe(339);
  });
  test('processExtraFields null', () => {
    const result = processExtraFields(false);
    expect(result).toBeFalsy();
  });
  test('processSections', () => {
    const result = processSections(pages.prefilled_market_modules);
    expect(result).toBeTruthy();
  });
  test('reading time', () => {
    const relationType = 'author';
    const market = 'ie_en';
    const page = {
      [market]: {
        [relationType]: getPageList({
          template: relationType,
          count: 3,
          relation: null,
          relation_id: 5,
        }),
      },
    };
    const result = getReadingTime(page[market][relationType][0].sections);
    page.reading_time = result;

    expect(result).toBe(1);
    expect(page.reading_time).toBeTruthy();
    expect(page.reading_time).toBe(result);

    // Add more content for testing purpose of longer reading time
    const page1 = {
      [market]: {
        [relationType]: getPageList({
          template: relationType,
          count: 3,
          relation: null,
          relation_id: 5,
        }),
      },
    };

    // eslint-disable-next-line no-plusplus
    for (let index = 0; index < 5; index++) {
      page1[market][relationType][1].sections.main.modules.push(tempContent);
    }
    const result1 = getReadingTime(page1[market][relationType][1].sections);
    page.reading_time = result1;

    expect(result1).toBe(11);
    expect(page.reading_time).toBeTruthy();
    expect(page.reading_time).toBe(result1);
  });
});
