/**
 * @description Factory to retrieve data related to top-list (Main or Sidebar)
 */

/**
 * @name getToplistItem
 * @description Mock top-list item data
 * @param {number} id - the id will be added to one_liner prop on main and on bonus
 * @return {Object} with top-list item structure
 */

export function getToplistItem(id = 1) {
  const oneLinerParam = `€${id}00 welcome bonus+${id}50 free spins`;
  const item = {
    name: `name${id}`,
    logo_url: `/logo${id}.jpg`,
    short_name: `shortName${id}`,
    type: 'operator',
    selling_points: ['1', '2', '3'],
    review_link: `link${id}`,
    one_liners: {
      main: {
        one_liner: oneLinerParam,
      },
      secondary: {
        one_liner: 'Welcome Bonus up to £1000',
      },
    },
    rating: '4',
    bonus: {
      one_liners: {
        main: {
          one_liner: oneLinerParam,
        },
        secondary: {
          one_liner: 'Welcome Bonus up to £1000',
        },
      },
    },
  };

  return item;
}

/**
 * @name getListToplistItem
 * @description Mock data for test top-list item
 * @param {number} totalItems - amount of items for the toplist
 * @return {Array} list with top-list item
 */
export function getListToplistItem(totalItems = 1) {
  const toplistItems = [];
  for (let i = 1; i <= totalItems; i += 1) {
    const toplistItem = getToplistItem(i);
    toplistItems.push(toplistItem);
  }
  return toplistItems;
}

/**
 * @name getListToplistItems
 * @description Mock data for test top-list items
 * @param {number} totalItems - amount of items for the toplist
 * @return {Array} list with top-list items
 */
export function getListToplistItems(totalItems = 1) {
  const toplistItems = [];
  for (let i = 1; i <= totalItems; i += 1) {
    const toplistItem = { items: getListToplistItem(i), title: `title${i}`, tracker: 'main' };
    toplistItems.push(toplistItem);
  }
  return toplistItems;
}

export const multiToplistData = {
  module_title: 'Multi Toplist',
  module_title_tag: 'h2',
  items: [
    {
      items: [
        {
          name: 'Rizk',
          type: 'casino',
          short_name: 'rizk',
          logo_url: 'rizk-logopng7ed316ac19-original.png',
          rating: '4',
          review_link: '/rizk',
          selling_points: ['200% Bonus', 'User-friendly'],
          one_liners: {
            main: {
              one_liner: '100% Bonus + 50 free spins',
            },
            secondary: {
              one_liner: 'Welcome Bonus up to £1000',
            },
          },
          extra_fields: {
            ribbon_color: '#17D68A',
            ribbon_text: 'Exclusive Bonus',
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Bet365',
          type: 'casino',
          short_name: 'bet365',
          operator_id: 6342,
          logo_url: 'image-63.png',
          rating: '3',
          review_link: '/bet365',
          selling_points: ['Over 1000 games', 'Loyalty Programme', 'Wager-free free spins'],
          one_liners: {
            main: {
              one_liner: 'Up to £100 New Player Bonus!',
            },
            secondary: {
              one_liner: '80% Bonus + 25 free spins',
            },
          },
          extra_fields: {
            ribbon_color: '#FFC740',
            ribbon_text: 'New',
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Captain Spins',
          type: 'casino',
          short_name: 'captain-spins',
          logo_url: 'captain-spins-logopng07b24ceb59-original.png',
          rating: '4',
          review_link: '/captain-spins',
          selling_points: ['Over 1000 games', 'Slick, modern interface'],
          one_liners: {
            main: {
              one_liner: '20% Bonus + 100 free spins',
            },
            secondary: {
              one_liner: '100% Bonus + 25 free spins',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
      ],
      tracker: 'main',
      one_liner: 'main',
      type: 'casino',
      title: 'Best Slots',
      show_load_more: '0',
      num_items_initial_load: '5',
      num_items_load_more: '5',
    },
    {
      items: [
        {
          name: 'Slotum',
          type: 'casino',
          short_name: 'slotum',
          logo_url: 'slotum-casino-logo-transparentpng6b10407566-original.png',
          rating: '4',
          review_link: '/slotum',
          selling_points: ['200% Bonus', 'Nice design'],
          one_liners: {
            main: {
              one_liner: '90% Bonus + 50 free spins',
            },
            secondary: {
              one_liner: 'Welcome Bonus up to £500',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Rizk',
          type: 'casino',
          short_name: 'rizk',
          logo_url: 'rizk-logopng7ed316ac19-original.png',
          rating: '4',
          review_link: '/rizk',
          selling_points: ['100% Bonus', 'User-friendly', 'Welcome bonus', 'Nice design'],
          one_liners: {
            main: {
              one_liner: '100% Bonus + 50 free spins',
            },
            secondary: {
              one_liner: 'Welcome Bonus up to £1000',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Casoola',
          type: 'casino',
          short_name: 'casoola',
          logo_url: 'casoola-logopng381ab5c04f-original.png',
          rating: '3',
          review_link: '/casoola',
          selling_points: ['25 free spins', 'Loyalty scheme'],
          one_liners: {
            main: {
              one_liner: '80% Bonus + 25 free spins',
            },
            secondary: {
              one_liner: 'Up to £100 New Player Bonus!',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Bet365',
          type: 'casino',
          short_name: 'bet365',
          logo_url: 'image-63.png',
          rating: '3',
          review_link: '/bet365',
          selling_points: ['Loyalty programme', 'Wager-free free spins'],
          one_liners: {
            main: {
              one_liner: 'Up to £100 New Player Bonus!',
            },
            secondary: {
              one_liner: '80% Bonus + 25 free spins',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Captain Spins',
          type: 'casino',
          short_name: 'captain-spins',
          logo_url: 'captain-spins-logopng07b24ceb59-original.png',
          rating: '4',
          review_link: '/captain-spins',
          selling_points: ['Over 1000 games', 'User-friendly'],
          one_liners: {
            main: {
              one_liner: '20% Bonus + 100 free spins',
            },
            secondary: {
              one_liner: '100% Bonus + 25 free spins',
            },
          },
        },
        {
          name: 'Casino Gods',
          type: 'casino',
          short_name: 'casino-gods',
          logo_url: 'casino-gods-logopng3bfc0d51-original.png',
          rating: '3',
          review_link: '/casino-gods',
          selling_points: ['Slick, modern interface', 'User-friendly', 'Over 500 games'],
          one_liners: {
            main: {
              one_liner: '100% Bonus + 50 free spins',
            },
            secondary: {
              one_liner: '25 free spins and deposit',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Jinni Lotto',
          type: 'casino',
          short_name: 'jinni-lotto',
          logo_url: 'jinnilotto-logopng464964d6b0-original.png',
          rating: '4',
          review_link: '/jinni-lotto',
          selling_points: ['90% Bonus', 'Nice design'],
          one_liners: {
            main: {
              one_liner: '90% Bonus + 100 free spins',
            },
            secondary: {
              one_liner: 'Up to £100 New Player Bonus!',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Betfair',
          type: 'casino',
          short_name: 'betfair',
          logo_url: '5aedeb23bb-original.png',
          rating: '5',
          review_link: '/betfair',
          selling_points: ['Loyalty programme', '100 free spins'],
          one_liners: {
            main: {
              one_liner: '100% Bonus + 100 free spins',
            },
            secondary: {
              one_liner: 'Up to £50 New Player Bonus!',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Casoola',
          type: 'casino',
          short_name: 'casoola',
          logo_url: 'casoola-logopng381ab5c04f-original.png',
          rating: '3',
          review_link: '/casoola',
          selling_points: ['Wager free', 'New player bonus'],
          one_liners: {
            main: {
              one_liner: '80% Bonus + 25 free spins',
            },
            secondary: {
              one_liner: 'Up to £100 New Player Bonus!',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Bet365',
          type: 'casino',
          short_name: 'bet365',
          logo_url: 'image-63.png',
          rating: '3',
          review_link: '/bet365',
          selling_points: ['User friendly'],
          one_liners: {
            main: {
              one_liner: 'Up to £100 New Player Bonus!',
            },
            secondary: {
              one_liner: '80% Bonus + 25 free spins',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Captain Spins',
          type: 'casino',
          short_name: 'captain-spins',
          logo_url: 'captain-spins-logopng07b24ceb59-original.png',
          rating: '4',
          review_link: '/captain-spins',
          selling_points: ['100 free spins', 'User-friendly', 'Nice design', 'Loyalty programme'],
          one_liners: {
            main: {
              one_liner: '20% Bonus + 100 free spins',
            },
            secondary: {
              one_liner: '100% Bonus + 25 free spins',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Slotum',
          type: 'casino',
          short_name: 'slotum',
          logo_url: 'slotum-casino-logo-transparentpng6b10407566-original.png',
          rating: '4',
          review_link: '/slotum',
          selling_points: ['Enticing welcome bonus', 'Free sign up'],
          one_liners: {
            main: {
              one_liner: '90% Bonus + 50 free spins',
            },
            secondary: {
              one_liner: 'Welcome Bonus up to £500',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Casoola',
          type: 'casino',
          short_name: 'casoola',
          logo_url: 'casoola-logopng381ab5c04f-original.png',
          rating: '3',
          review_link: '/casoola',
          selling_points: ['80% Bonus', 'User-friendly'],
          one_liners: {
            main: {
              one_liner: '80% Bonus + 25 free spins',
            },
            secondary: {
              one_liner: 'Up to £100 New Player Bonus!',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
      ],
      tracker: 'main',
      show_load_more: '1',
      num_items_initial_load: '5',
      num_items_load_more: '5',
      one_liner: 'main',
      type: 'casino',
      title: 'With Load More',
    },
  ],
};

export const singleToplistData = {
  module_title: 'Single Toplist',
  module_title_tag: 'h2',
  items: [
    {
      items: [
        {
          name: 'Slotum',
          type: 'casino',
          operator_id: 6342,
          bonus: {
            deposit_methods: ['test'],
          },
          short_name: 'slotum',
          logo_url: 'slotum-casino-logo-transparentpng6b10407566-original.png',
          rating: '4',
          review_link: 'slotum',
          selling_points: ['200% Bonus', 'Nice design'],
          links: {
            main: 'https://media.dunderaffiliates.com/redirect.aspx?pid=630524&bid=1477',
            'PPC Fallback': 'https://media.dunderaffiliates.com/redirect.aspx?pid=740444&bid=1803',
          },
          one_liners: {
            main: {
              one_liner: '90% Bonus + 50 free spins',
            },
            secondary: {
              one_liner: 'Welcome Bonus up to £500',
            },
          },
          extra_fields: {
            ribbon_color: '#17D68A',
            ribbon_text: 'Exclusive Bonus',
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Rizk',
          type: 'casino',
          operator_id: 6342,
          bonus: {
            deposit_methods: [],
          },
          short_name: 'rizk',
          logo_url: 'rizk-logopng7ed316ac19-original.png',
          rating: '4',
          review_link: '/rizk',
          selling_points: ['100% Bonus', 'User-friendly', 'Welcome bonus', 'Nice design'],
          links: {
            main: 'https://media.dunderaffiliates.com/redirect.aspx?pid=630524&bid=1477',
            'PPC Fallback': 'https://media.dunderaffiliates.com/redirect.aspx?pid=740444&bid=1803',
          },
          one_liners: {
            main: {
              one_liner: '100% Bonus + 50 free spins',
            },
            secondary: {
              one_liner: 'Welcome Bonus up to £1000',
            },
          },
          extra_fields: {
            ribbon_color: '#FFC740',
            ribbon_text: 'New',
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Casoola',
          type: 'casino',
          operator_id: 6342,
          bonus: {
            deposit_methods: [],
          },
          short_name: 'casoola',
          logo_url: 'casoola-logopng381ab5c04f-original.png',
          rating: '3',
          review_link: '/casoola',
          selling_points: ['25 free spins', 'Loyalty scheme'],
          links: {
            main: 'https://media.dunderaffiliates.com/redirect.aspx?pid=630524&bid=1477',
            'PPC Fallback': 'https://media.dunderaffiliates.com/redirect.aspx?pid=740444&bid=1803',
          },
          one_liners: {
            main: {
              one_liner: '80% Bonus + 25 free spins',
            },
            secondary: {
              one_liner: 'Up to £100 New Player Bonus!',
            },
          },
        },
        {
          name: 'Bet365',
          type: 'casino',
          operator_id: 6342,
          bonus: {
            deposit_methods: [],
          },
          short_name: 'bet365',
          logo_url: 'image-63.png',
          rating: '3',
          review_link: '/bet365',
          selling_points: ['Loyalty programme', 'Wager-free free spins'],
          links: {
            main: 'https://media.dunderaffiliates.com/redirect.aspx?pid=630524&bid=1477',
            'PPC Fallback': 'https://media.dunderaffiliates.com/redirect.aspx?pid=740444&bid=1803',
          },
          one_liners: {
            main: {
              one_liner: 'Up to £100 New Player Bonus!',
            },
            secondary: {
              one_liner: '80% Bonus + 25 free spins',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Captain Spins',
          type: 'casino',
          operator_id: 6342,
          bonus: {
            deposit_methods: [],
          },
          links: {
            main: 'https://media.dunderaffiliates.com/redirect.aspx?pid=630524&bid=1477',
            'PPC Fallback': 'https://media.dunderaffiliates.com/redirect.aspx?pid=740444&bid=1803',
          },
          short_name: 'captain-spins',
          logo_url: 'captain-spins-logopng07b24ceb59-original.png',
          rating: '4',
          review_link: '/captain-spins',
          selling_points: ['Over 1000 games', 'User-friendly'],
          one_liners: {
            main: {
              one_liner: '20% Bonus + 100 free spins',
            },
            secondary: {
              one_liner: '100% Bonus + 25 free spins',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Casino Gods',
          type: 'casino',
          operator_id: 6342,
          bonus: {
            deposit_methods: [],
          },
          links: {
            main: 'https://media.dunderaffiliates.com/redirect.aspx?pid=630524&bid=1477',
            'PPC Fallback': 'https://media.dunderaffiliates.com/redirect.aspx?pid=740444&bid=1803',
          },
          short_name: 'casino-gods',
          logo_url: 'casino-gods-logopng3bfc0d51-original.png',
          rating: '3',
          review_link: '/casino-gods',
          selling_points: ['Slick, modern interface', 'User-friendly', 'Over 500 games'],
          one_liners: {
            main: {
              one_liner: '100% Bonus + 50 free spins',
            },
            secondary: {
              one_liner: '25 free spins and deposit',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Jinni Lotto',
          type: 'casino',
          operator_id: 6342,
          bonus: {
            deposit_methods: [],
          },
          links: {
            main: 'https://media.dunderaffiliates.com/redirect.aspx?pid=630524&bid=1477',
            'PPC Fallback': 'https://media.dunderaffiliates.com/redirect.aspx?pid=740444&bid=1803',
          },
          short_name: 'jinni-lotto',
          logo_url: 'jinnilotto-logopng464964d6b0-original.png',
          rating: '4',
          review_link: '/jinni-lotto',
          selling_points: ['90% Bonus', 'Nice design'],
          one_liners: {
            main: {
              one_liner: '90% Bonus + 100 free spins',
            },
            secondary: {
              one_liner: 'Up to £100 New Player Bonus!',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Betfair',
          type: 'casino',
          operator_id: 6342,
          bonus: {
            deposit_methods: [],
          },
          links: {
            main: 'https://media.dunderaffiliates.com/redirect.aspx?pid=630524&bid=1477',
            'PPC Fallback': 'https://media.dunderaffiliates.com/redirect.aspx?pid=740444&bid=1803',
          },
          short_name: 'betfair',
          logo_url: '5aedeb23bb-original.png',
          rating: '5',
          review_link: '/betfair',
          selling_points: ['Loyalty programme', '100 free spins'],
          one_liners: {
            main: {
              one_liner: '100% Bonus + 100 free spins',
            },
            secondary: {
              one_liner: 'Up to £50 New Player Bonus!',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Casoola',
          type: 'casino',
          operator_id: 6342,
          bonus: {
            deposit_methods: [],
          },
          links: {
            main: 'https://media.dunderaffiliates.com/redirect.aspx?pid=630524&bid=1477',
            'PPC Fallback': 'https://media.dunderaffiliates.com/redirect.aspx?pid=740444&bid=1803',
          },
          short_name: 'casoola',
          logo_url: 'casoola-logopng381ab5c04f-original.png',
          rating: '3',
          review_link: '/casoola',
          selling_points: ['Wager free', 'New player bonus'],
          one_liners: {
            main: {
              one_liner: '80% Bonus + 25 free spins',
            },
            secondary: {
              one_liner: 'Up to £100 New Player Bonus!',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Bet365',
          type: 'casino',
          operator_id: 6342,
          bonus: {
            deposit_methods: [],
          },
          links: {
            main: 'https://media.dunderaffiliates.com/redirect.aspx?pid=630524&bid=1477',
            'PPC Fallback': 'https://media.dunderaffiliates.com/redirect.aspx?pid=740444&bid=1803',
          },
          short_name: 'bet365',
          logo_url: 'image-63.png',
          rating: '3',
          review_link: '/bet365',
          selling_points: ['User friendly'],
          one_liners: {
            main: {
              one_liner: 'Up to £100 New Player Bonus!',
            },
            secondary: {
              one_liner: '80% Bonus + 25 free spins',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Captain Spins',
          type: 'casino',
          operator_id: 6342,
          bonus: {
            deposit_methods: [],
          },
          links: {
            main: 'https://media.dunderaffiliates.com/redirect.aspx?pid=630524&bid=1477',
            'PPC Fallback': 'https://media.dunderaffiliates.com/redirect.aspx?pid=740444&bid=1803',
          },
          short_name: 'captain-spins',
          logo_url: 'captain-spins-logopng07b24ceb59-original.png',
          rating: '4',
          review_link: '/captain-spins',
          selling_points: ['100 free spins', 'User-friendly', 'Nice design', 'Loyalty programme'],
          one_liners: {
            main: {
              one_liner: '20% Bonus + 100 free spins',
            },
            secondary: {
              one_liner: '100% Bonus + 25 free spins',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Slotum',
          type: 'casino',
          operator_id: 6342,
          bonus: {
            deposit_methods: [],
          },
          links: {
            main: 'https://media.dunderaffiliates.com/redirect.aspx?pid=630524&bid=1477',
            'PPC Fallback': 'https://media.dunderaffiliates.com/redirect.aspx?pid=740444&bid=1803',
          },
          short_name: 'slotum',
          logo_url: 'slotum-casino-logo-transparentpng6b10407566-original.png',
          rating: '4',
          review_link: '/slotum',
          selling_points: ['Enticing welcome bonus', 'Free sign up'],
          one_liners: {
            main: {
              one_liner: '90% Bonus + 50 free spins',
            },
            secondary: {
              one_liner: 'Welcome Bonus up to £500',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
        {
          name: 'Casoola',
          type: 'casino',
          operator_id: 6342,
          bonus: {
            deposit_methods: [],
          },
          links: {
            main: 'https://media.dunderaffiliates.com/redirect.aspx?pid=630524&bid=1477',
            'PPC Fallback': 'https://media.dunderaffiliates.com/redirect.aspx?pid=740444&bid=1803',
          },
          short_name: 'casoola',
          logo_url: 'casoola-logopng381ab5c04f-original.png',
          rating: '3',
          review_link: '/casoola',
          selling_points: ['80% Bonus', 'User-friendly'],
          one_liners: {
            main: {
              one_liner: '80% Bonus + 25 free spins',
            },
            secondary: {
              one_liner: 'Up to £100 New Player Bonus!',
            },
          },
          extra_fields: {
            terms_and_conditions_text_enabled: '1',
          },
        },
      ],
      tracker: 'main',
      one_liner: 'main',
      type: 'casino',
      title: 'With Load More',
      show_load_more: '1',
      num_items_initial_load: '10',
      num_items_load_more: '3',
    },
  ],
};

export const relationData = {
  operator: {
    6342: {
      id: 6342,
      market_id: 25,
      operator_id: 319,
      review_link: 'http://www.irishluck.ie/dunder-casino-review/',
      rating_casino: '4',
      rating_games: '4.3',
      rating_bonuses: '4.3',
      rating_customer: '4.5',
      rating_payout: '',
      rating: '4.3',
      selling_points: [],
      per_site_enabled: true,
      status: 'active',
      date_last_modified: '2020-10-06',
      links: {
        main: 'https://media.dunderaffiliates.com/redirect.aspx?pid=630524&bid=1477',
        'PPC Fallback': 'https://media.dunderaffiliates.com/redirect.aspx?pid=740444&bid=1803',
      },
      custom_links: [],
      owner: 'Burstit Limited',
      types: ['casino'],
      type: 'casino',
      deposit_wagering: '0x',
      support_types: 'Live chat, Email, Vip Support',
      bonus: {
        deposit_methods: ['asd', 'asd'],
      },
      software: [
        {
          id: 2,
          name: '2by2 Gaming',
          short_name: '2_by_2_gaming',
          logo_asset_id: 10737,
          games_count: 1,
          updated_at: null,
        },
        {
          id: 5,
          name: 'Amaya',
          short_name: 'amaya',
          logo_asset_id: 0,
          games_count: 0,
          updated_at: null,
        },
      ],
      one_liners: {
        main: {
          one_liner: '€100 Welcome bonus+ 120 Free Spins',
          start_date: null,
          end_date: null,
          categories: [],
          percentage: '',
          amount: '',
          freespins: '',
          freemoney: '',
          freespins_nodeposit_amount: '',
          freespins_nodeposit_bonuscode: '',
          freespins_nodeposit_games: '',
        },
      },
    },
  },
};
